@@ -284,6 +284,14 @@ sail_status_t bmp_private_read_init(struct sail_io *io, const struct sail_load_o
             SAIL_LOG_AND_RETURN(SAIL_ERROR_MISSING_PALETTE);
         }
 
+        /* Validate and allocate palette. */
+        size_t max_palette_count = SIZE_MAX / sizeof(sail_rgba32_t);
+
+        if (bmp_state->palette_count > max_palette_count) {
+            SAIL_LOG_ERROR("BMP: Indexed image has too large palette");
+            SAIL_LOG_AND_RETURN(SAIL_ERROR_BROKEN_IMAGE);
+        }
+
         void *ptr;
         SAIL_TRY(sail_malloc(sizeof(sail_rgba32_t) * bmp_state->palette_count, &ptr));
         bmp_state->palette = ptr;
@@ -508,6 +516,9 @@ sail_status_t bmp_private_read_frame(void *state, struct sail_io *io, struct sai
                     uint8_t index;
                     SAIL_TRY(io->strict_read(io->stream, &index, sizeof(index)));
 
+                    /* Round to the buffer size. */
+                    marker = (pixel_index + marker) <= image->width ? marker : (image->width - pixel_index);
+
                     for (uint8_t k = 0; k < marker; k++) {
                         *scan++ = index;
                     }
